rm(list = ls())

frey2001 <- read_csv("data/clean/simulations_frey.csv")

frey2001 %>% 
  group_by(simulation_id) %>% 
  nest()


rss <- function(par, data) {
  
  y <- data$par_d_p24h_ein_m_2_day_1
  x <- data$depth
  
  
  i0 <- par[1]
  kd <- par[2]
  kns <- par[3]
  ins <- par[4]
  
  yy <- calculate_light(par, x)
  
  rss <- sum((y - yy)^2, na.rm = TRUE)
  
  return(rss)
  
}

calculate_light <- function(par, x) {
  
  i0 <- par[1]
  kd <- par[2]
  kns <- par[3]
  ins <- par[4]
  
  yy <- i0 * exp(-kd * x) - (i0 - ins) * exp(-kns * x)
  
  return(yy)
  
}

fit_model <- function(df) {
  
  mod <- optim(par = c(
    i0 = 0.1,
    kd = 0.02,
    kns = 0.02,
    ins = 0.1),
    lower = c(
      i0 = 0,
      kd = 0.001,
      kns = 0,
      ins = 0.01
    ),
    upper = c(
      i0 = 500,
      kd = 0.1,
      kns = 1,
      ins = 1
    ),
    rss,
    data = df)
  
  return(mod)
  
}

## Predict light using the model generated by "optim".
predict_light <- function(data, model) {
  
  pred <- calculate_light(model$par, data$depth)
  # pred <- data_frame(depth = data$depth, pred = pred)
  return(pred)
}

res <- frey2001 %>% 
  group_by(simulation_id, k) %>% 
  nest() %>% 
  mutate(model = map(data, fit_model)) %>% 
  mutate(pred = map2(data, model, predict_light)) %>% 
  mutate(kd = map(model, function(x) x$par[2]))

res %>% 
  unnest(kd) %>% 
  ggplot(aes(x = k, y = kd)) +
  geom_point() +
  geom_abline(intercept = 0, slope = 1)

# Test on cops data -------------------------------------------------------

cops <- read_csv("data/clean/cops.csv") %>% 
  filter(hole_type == "H")

res <- cops %>% 
  group_by(profile_filename) %>% 
  nest() %>% 
  mutate(model = map(data, fit_model)) %>% 
  mutate(pred = map2(data, model, predict_light))

res %>% 
  unnest(data, pred) %>% 
  ggplot(aes(x = par_d_p24h_ein_m_2_day_1, y = depth)) +
  geom_point() +
  geom_path(aes(x = pred), color = "red") +
  facet_wrap(~profile_filename, scales = "free") +
  scale_y_reverse()

