# <><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>
# AUTHOR:       Philippe Massicotte
#
# DESCRIPTION:
#
# Compare Ed and Lu profiles generated by SimulO with and without melt ponds.
# <><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>

rm(list = ls())

source("R/simulo/tidy_simulo.R")


# Read SimulO data --------------------------------------------------------

simulo_melt_pond <- read_feather("data/clean/simulo/compute-canada/simulo.feather")
load("data/clean/simulo/edouard/SimulKd_NoMeltP_150m.RData")
simulo_open_water <- tidy_simulo(DataS)
rm(DataS)

df <- list(simulo_melt_pond = simulo_melt_pond, simulo_open_water = simulo_open_water) %>%
  bind_rows(.id = "type") %>%
  filter(source == "intensity") %>%
  filter(pixel_distance_to_center <= 50) %>%
  mutate(id = interaction(type, source, x, y))

# Plot individual profiles and mean profiles ------------------------------

res <- df %>%
  group_by(type, depth) %>%
  summarise(value = mean(value))

p1 <- df %>%
  ggplot(aes(x = value, y = depth)) +
  geom_path(aes(group = interaction(x, y)), size = 0.25, alpha = 0.25) +
  scale_y_reverse() +
  facet_wrap(~ type, scales = "free") +
  geom_line(data = res, aes(x = value, y = depth, color = "Mean profile")) +
  labs(title = "Ed profiles from SimulO") +
  theme(legend.title = element_blank()) +
  scale_x_continuous(labels = scales::scientific)

## Normalize
res <- res %>%
  group_by(type) %>%
  mutate(value = value / max(value)) %>%
  ungroup()

p2 <- res %>%
  ggplot(aes(x = value, y = depth, color = type)) +
  geom_path() +
  scale_y_reverse() +
  labs(title = "Normalized mean profiles from panel A") +
  labs(subtitle = "Both mean Ed profiles fit perfectly") +
  theme(legend.title = element_blank())

p <- cowplot::plot_grid(p1, p2, nrow = 1, labels = "AUTO", rel_widths = c(0.50, 0.25))
ggsave("graphs/simulo_compare_ed_melt_pond_and_open_water.pdf", device = cairo_pdf, width = 24, height = 6)

# Stats -------------------------------------------------------------------

res %>%
  spread(type, value) %>%
  ggplot(aes(x = simulo_melt_pond, y = simulo_open_water)) +
  geom_point() +
  geom_abline(lty = 2)
